@@ -12,22 +12,24 @@ class adventuretablet(gobject.GObject):
     def __init__(self):
         gobject.GObject.__init__(self)
 
+
         # Display splash screen while the app initializes
         self.splash = gtk.Window()
         self.splash.set_title('the Tablet of Adventure')
         # TODO: Display a picture of unicorns, kittens and ponies
         vbox = gtk.VBox(False, 0)
-        #pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(os.path.abspath(os.path.dirname(__file__)) + "/blue.png", 200,200)
-        #image = gtk.Image()
-        #image.set_from_pixbuf(pixbuf)
-        #image.show()
-        self.status = gtk.Label()
-        self.status.set_text("Initializing...")
-        self.status.show()
-        #vbox.pack_start(image)
-        vbox.pack_start(self.status)
+        pixbuf = gtk.gdk.pixbuf_new_from_file(os.path.abspath(os.path.dirname(__file__)) + "/splash.jpg")
+        image = gtk.Image()
+        image.set_from_pixbuf(pixbuf)
+        image.show()
+        #self.status = gtk.Label()
+        #self.status.set_text("Initializing...")
+        #self.status.show()
+        vbox.pack_start(image)
+        #vbox.pack_start(self.status)
         self.splash.add(vbox)
         vbox.show()
+        self.splash.fullscreen()
         self.splash.show()
 
         hildon.hildon_gtk_window_set_progress_indicator(self.splash, 1)
@@ -37,7 +39,7 @@ class adventuretablet(gobject.GObject):
 
         # Tell GLib to prepare Midgard and show game when ready
         self.connect('storage-ready', self.prepare_game)
-        gobject.timeout_add(50, self.prepare_midgard)
+        gobject.idle_add(self.prepare_midgard)
 
     def prepare_midgard(self):
         #self.status.set_text("Initializing Midgard connection...")
